@@ -52,11 +52,10 @@
 #include "kmagselrect.h"
 
 
-KmagApp::KmagApp(QWidget* , const char* name)
+KmagApp::KmagApp(QWidget*)
   : KXmlGuiWindow(nullptr) // Qt::WStyle_MinMax | Qt::WType_TopLevel | Qt::WDestructiveClose | Qt::WStyle_ContextHelp | Qt::WindowCloseButtonHint | Qt::WStyle_StaysOnTop
   , m_defaultMouseCursorType(2)
 {
-  setObjectName( QLatin1String( name ) );
   setWindowFlags(windowFlags() | Qt::WindowStaysOnTopHint);
   config=KSharedConfig::openConfig();
 
@@ -98,10 +97,6 @@ KmagApp::KmagApp(QWidget* , const char* name)
 
   // read options from config file
   readOptions();
-
-  #ifndef QT_NO_PRINTER
-  m_printer = nullptr;
-  #endif // QT_NO_PRINTER
 }
 
 /**
